@@ -8,17 +8,17 @@ test.removal <- function() {
         2, 0, 0,
         0, 0, 0,
         0, 0, 0), nrow=5, ncol=3, byrow=TRUE)
-    
+
     sc <- data.frame(x1 = c(NA, 2, 3, 4, 3))
     oc <- list(x2 = matrix(c(
         1, 1, 1,
         3, NA, 1,
         0, 0, 1,
         NA, NA, NA,
-        NA, 1, 0), nrow=5, ncol=3, byrow=TRUE)) 
-    
-    umf1 <- unmarkedFrameMPois(y = y, siteCovs = sc, obsCovs = oc, 
-        type="removal") 
+        NA, 1, 0), nrow=5, ncol=3, byrow=TRUE))
+
+    umf1 <- unmarkedFrameMPois(y = y, siteCovs = sc, obsCovs = oc,
+        type="removal")
 
     o2y <- diag(ncol(y))
     o2y[upper.tri(o2y)] <- 1
@@ -34,18 +34,21 @@ test.removal <- function() {
     checkEqualsNumeric(coef(m2_R), c(1.9159845, 0.2248897, -0.1808144), tol=1e-5)
     checkEquals(m2_R@sitesRemoved, 4:5)
     checkEqualsNumeric(coef(m2_R),coef(m2_C), tol=1e-5)
-    
+
     m3_R <- multinomPois(~x2 ~x1, umf1, engine="R")
     m3_C <- multinomPois(~x2 ~x1, umf1, engine="C")
     checkEqualsNumeric(m3_R@sitesRemoved, c(1, 4:5))
-    checkEqualsNumeric(coef(m3_R), 
-        c(1.9118525, -0.4071202, 8.3569943, 0.3232485), tol=1e-5)    
+    checkEqualsNumeric(coef(m3_R),
+        c(1.9118525, -0.4071202, 8.3569943, 0.3232485), tol=1e-5)
     checkEqualsNumeric(coef(m3_R),coef(m3_C), tol=1e-5)
 
-    }
-    
-    
-    
+    #Check error when random effect in formula
+    checkException(multinomPois(~(1|dummy) ~1, umf1))
+
+}
+
+
+
 test.double <- function() {
     y <- matrix(c(
         1, 0, 0,
@@ -61,16 +64,16 @@ test.double <- function() {
         NA, 0,
         1, NA,
         NA, NA), nrow=6, ncol=2, byrow=TRUE)
-        
-    umf <- unmarkedFrameMPois(y = y, obsCovs = list(x=oc), type="double")    
-    
+
+    umf <- unmarkedFrameMPois(y = y, obsCovs = list(x=oc), type="double")
+
     m1_R <- multinomPois(~1 ~1, umf, engine="R")
     m1_C <- multinomPois(~1 ~1, umf, engine="C")
     checkEqualsNumeric(coef(m1_R), c(1.3137876, 0.2411609), tol=1e-5)
     checkEqualsNumeric(coef(m1_R),coef(m1_C))
 
     m2 <- multinomPois(~x ~1, umf, starts=c(1.3, 0, 0.2))
-    checkEquals(m2@sitesRemoved, 4:6)    
+    checkEquals(m2@sitesRemoved, 4:6)
     }
 
-      
+
